@@ -1,5 +1,5 @@
 /* This file is part of GNU cflow
-   Copyright (C) 1997-2019 Sergey Poznyakoff
+   Copyright (C) 1997-2021 Sergey Poznyakoff
  
    GNU cflow is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,9 +23,7 @@
 #include <version-etc.h>
 
 const char *argp_program_bug_address = "<" PACKAGE_BUGREPORT ">";
-static char doc[] = N_("generate a program flowgraph")
-"\v"
-N_("* The effect of each option marked with an asterisk is reversed if the option's long name is prefixed with `no-'. For example, --no-cpp cancels --cpp.");
+static char doc[] = N_("generate a program flowgraph");
 const char *program_authors[] = {
      "Sergey Poznyakoff",
      NULL
@@ -59,24 +57,24 @@ static struct argp_option options[] = {
      { NULL, 0, NULL, 0,
        N_("General options:"), GROUP_ID },
      { "depth", 'd', N_("NUMBER"), 0,
-       N_("Set the depth at which the flowgraph is cut off"), GROUP_ID+1 },
+       N_("set the depth at which the flowgraph is cut off"), GROUP_ID+1 },
      { "include", 'i', N_("CLASSES"), 0,
-       N_("Include specified classes of symbols (see below). Prepend CLASSES with ^ or - to exclude them from the output"), GROUP_ID+1 },
+       N_("include specified classes of symbols (see below). Prepend CLASSES with ^ or - to exclude them from the output"), GROUP_ID+1 },
      { "format", 'f', N_("NAME"), 0,
-       N_("Use given output format NAME. Valid names are `gnu' (default) and `posix'"),
+       N_("use given output format NAME. Valid names are `gnu' (default) and `posix'"),
        GROUP_ID+1 },
      { "reverse", 'r', NULL, 0,
-       N_("* Print reverse call tree"), GROUP_ID+1 },
+       N_("print reverse call tree"), GROUP_ID+1 },
      { "xref", 'x', NULL, 0,
-       N_("Produce cross-reference listing only"), GROUP_ID+1 },
+       N_("produce cross-reference listing only"), GROUP_ID+1 },
      { "print", 'P', N_("OPT"), OPTION_HIDDEN,
-       N_("Set printing option to OPT. Valid OPT values are: xref (or cross-ref), tree. Any unambiguous abbreviation of the above is also accepted"),
+       N_("set printing option to OPT. Valid OPT values are: xref (or cross-ref), tree. Any unambiguous abbreviation of the above is also accepted"),
        GROUP_ID+1 },
      { "output", 'o', N_("FILE"), 0,
-       N_("Set output file name (default -, meaning stdout)"),
+       N_("set output file name (default -, meaning stdout)"),
        GROUP_ID+1 },
 
-     { NULL, 0, NULL, 0, N_("Symbols classes for --include argument"), GROUP_ID+2 },
+     { NULL, 0, NULL, 0, N_("Symbol classes for --include argument"), GROUP_ID+2 },
      {"  x", 0, NULL, OPTION_DOC|OPTION_NO_TRANS,
       N_("all data symbols, both external and static"), GROUP_ID+3 },
      {"  _",  0, NULL, OPTION_DOC|OPTION_NO_TRANS,
@@ -92,80 +90,80 @@ static struct argp_option options[] = {
      { NULL, 0, NULL, 0,
        N_("Parser control:"), GROUP_ID },
      { "use-indentation", 'S', NULL, 0,
-       N_("* Rely on indentation"), GROUP_ID+1 },
-     { "no-use-indentation", OPT_NO_USE_INDENTATION, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("rely on indentation"), GROUP_ID+1 },
+     { "no-use-indentation", OPT_NO_USE_INDENTATION, NULL, 0,
+       N_("don't rely on intentation (default)"), GROUP_ID+1 },
      { "ansi", 'a', NULL, 0,
-       N_("* Accept only sources in ANSI C"), GROUP_ID+1 },
-     { "no-ansi", OPT_NO_ANSI, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("accept only sources in ANSI C"), GROUP_ID+1 },
+     { "no-ansi", OPT_NO_ANSI, NULL, 0,
+       N_("accept both ANSI and K&R C (default)"), GROUP_ID+1 },
      { "pushdown", 'p', N_("NUMBER"), 0,
-       N_("Set initial token stack size to NUMBER"), GROUP_ID+1 },
+       N_("set initial token stack size to NUMBER"), GROUP_ID+1 },
      { "symbol", 's', N_("SYMBOL:[=]TYPE"), 0,
-       N_("Register SYMBOL with given TYPE, or define an alias (if := is used). Valid types are: keyword (or kw), modifier, qualifier, identifier, type, wrapper. Any unambiguous abbreviation of the above is also accepted"), GROUP_ID+1 },
+       N_("register SYMBOL with given TYPE, or define an alias (if := is used). Valid types are: keyword (or kw), modifier, qualifier, identifier, type, wrapper. Any unambiguous abbreviation of the above is also accepted"), GROUP_ID+1 },
      { "main", 'm', N_("NAME"), 0,
-       N_("Assume main function to be called NAME"), GROUP_ID+1 },
+       N_("assume main function to be called NAME"), GROUP_ID+1 },
      { "no-main", OPT_NO_MAIN, NULL, 0,
-       N_("There's no main function; print graphs for all functions in the program") },
+       N_("there's no main function; print graphs for all functions in the program") },
      { "define", 'D', N_("NAME[=DEFN]"), 0,
-       N_("Predefine NAME as a macro"), GROUP_ID+1 },
+       N_("predefine NAME as a macro"), GROUP_ID+1 },
      { "undefine", 'U', N_("NAME"), 0,
-       N_("Cancel any previous definition of NAME"), GROUP_ID+1 },
+       N_("cancel any previous definition of NAME"), GROUP_ID+1 },
      { "include-dir", 'I', N_("DIR"), 0,
-       N_("Add the directory DIR to the list of directories to be searched for header files."), GROUP_ID+1 },
+       N_("add the directory DIR to the list of directories to be searched for header files."), GROUP_ID+1 },
      { "preprocess", OPT_PREPROCESS, N_("COMMAND"), OPTION_ARG_OPTIONAL,
-       N_("* Run the specified preprocessor command"), GROUP_ID+1 },
+       N_("run the specified preprocessor command"), GROUP_ID+1 },
      { "cpp", 0, NULL, OPTION_ALIAS, NULL, GROUP_ID+1 },
-     { "no-preprocess", OPT_NO_PREPROCESS, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
-     { "no-cpp", 0, NULL, OPTION_ALIAS|OPTION_HIDDEN, NULL, GROUP_ID+1 },
+     { "no-preprocess", OPT_NO_PREPROCESS, NULL, 0,
+       N_("disable preprocessor"), GROUP_ID+1 },
+     { "no-cpp", 0, NULL, OPTION_ALIAS, NULL, GROUP_ID+1 },
 #undef GROUP_ID
 #define GROUP_ID 20          
      { NULL, 0, NULL, 0,
-       N_("Output control:"), GROUP_ID },
+       N_("output control:"), GROUP_ID },
      { "all", 'A', NULL, 0,
-       N_("Show all functions, not only those reachable from main"),
+       N_("show all functions, not only those reachable from main"),
        GROUP_ID+1 },
      { "number", 'n', NULL, 0,
-       N_("* Print line numbers"), GROUP_ID+1 },
-     { "no-number", OPT_NO_NUMBER, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("print line numbers"), GROUP_ID+1 },
+     { "no-number", OPT_NO_NUMBER, NULL, 0,
+       N_("don't print line numbers (default)"), GROUP_ID+1 },
      { "print-level", 'l', NULL, 0,
-       N_("* Print nesting level along with the call tree"), GROUP_ID+1 },
-     { "no-print-level", OPT_NO_PRINT_LEVEL, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("print nesting level along with the call tree"), GROUP_ID+1 },
+     { "no-print-level", OPT_NO_PRINT_LEVEL, NULL, 0,
+       N_("don't print nesting levels (default)"), GROUP_ID+1 },
      { "level-indent", OPT_LEVEL_INDENT, "ELEMENT", 0,
-       N_("Control graph appearance"), GROUP_ID+1 },
+       N_("control graph appearance"), GROUP_ID+1 },
      { "tree", 'T', NULL, 0,
-       N_("* Draw ASCII art tree"), GROUP_ID+1 },
-     { "no-tree", OPT_NO_TREE, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("draw ASCII art tree"), GROUP_ID+1 },
+     { "no-tree", OPT_NO_TREE, NULL, 0,
+       N_("don't draw ASCII art tree (default)"), GROUP_ID+1 },
      { "brief", 'b', NULL, 0,
-       N_("* Brief output"), GROUP_ID+1 },
-     { "no-brief", OPT_NO_BRIEF, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("brief output"), GROUP_ID+1 },
+     { "no-brief", OPT_NO_BRIEF, NULL, 0,
+       N_("full output (default)"), GROUP_ID+1 },
      { "emacs", OPT_EMACS, NULL, 0,
-       N_("* Additionally format output for use with GNU Emacs"), GROUP_ID+1 },
-     { "no-emacs", OPT_NO_EMACS, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("additionally format output for use with GNU Emacs"), GROUP_ID+1 },
+     { "no-emacs", OPT_NO_EMACS, NULL, 0,
+       N_("don't format output for Emacs (default)"), GROUP_ID+1 },
      { "omit-arguments", OPT_OMIT_ARGUMENTS, NULL, 0,
-       N_("* Do not print argument lists in function declarations"), GROUP_ID+1 },
-     { "no-ignore-arguments", OPT_NO_OMIT_ARGUMENTS, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("don't print argument lists in function declarations"), GROUP_ID+1 },
+     { "no-omit-arguments", OPT_NO_OMIT_ARGUMENTS, NULL, 0,
+       N_("print argument lists in function declarations (default)"), GROUP_ID+1 },
      { "omit-symbol-names", OPT_OMIT_SYMBOL_NAMES, NULL, 0,
-       N_("* Do not print symbol names in declaration strings"), GROUP_ID+1 },
-     { "no-omit-symbol-names", OPT_NO_OMIT_SYMBOL_NAMES, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("don't print symbol names in declaration strings"), GROUP_ID+1 },
+     { "no-omit-symbol-names", OPT_NO_OMIT_SYMBOL_NAMES, NULL, 0,
+       N_("print symbol names in declaration strings (default)"), GROUP_ID+1 },
 #undef GROUP_ID
 #define GROUP_ID 30                 
      { NULL, 0, NULL, 0,
        N_("Informational options:"), GROUP_ID },
      { "verbose", 'v', NULL, 0,
-       N_("* Verbose error diagnostics"), GROUP_ID+1 },
-     { "no-verbose", OPT_NO_VERBOSE, NULL, OPTION_HIDDEN,
-       "", GROUP_ID+1 },
+       N_("verbose error diagnostics"), GROUP_ID+1 },
+     { "no-verbose", OPT_NO_VERBOSE, NULL, 0,
+       N_("disable verbose diagnostics (default)"), GROUP_ID+1 },
      { "debug", OPT_DEBUG, "NUMBER", OPTION_ARG_OPTIONAL,
-       N_("Set debugging level"), GROUP_ID+1 },
+       N_("set debugging level"), GROUP_ID+1 },
 #undef GROUP_ID     
      { 0, }
 };
